/* SISTEMAS INTEGRADOS TECNISA
   FINANCEIRO

NOME: ATUALIZA_FLUXO_DE_CAIXA.SQL

DESCRIO:
ATUALIZA O MOVIMENTO DE FLUXO DE CAIXA.

P_CDEMPRESA   - CDIGO DA EMPRESA.
P_CDFILIAL    - CDIGO DA FILIAL.
P_DTMOVFLUXO  - DATA DO MOVIMENTO DE FLUXO.
P_IDMOVFLUXO  - IDENTIFICADOR DO TIPO DE MOVIMENTO DE FLUXO
                "R" REAL
                "E" ESTIMADO
P_CDCLASSFINA - CDIGO DA CLASSIFICAO FINANCEIRA.
P_VRENTMFLUXO - VALOR DE ENTRADA DO MOVIMENTO DE FLUXO.
P_VRSAIMFLUXO - VALOR DE SADA DO MOVIMENTO DE FLUXO.

PARA APLICAR E DEBUGAR
-- @H:\SISTEMAS\DBA\SQL\ORACLE\1001_FINSTP_ATUALIZA_FLUXO_DE_CAIXA.SQL;
-- EXECUTE ATUALIZA_FLUXO_DE_CAIXA()
-- SET SERVEROUTPUT ON
-- DBMS_OUTPUT.PUT_LINE('XX');

CRIAO:
11/05/99 - EDERSON
*/

IF EXISTS (SELECT
              *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE
	           O.NAME = 'ATUALIZA_FLUXO_DE_CAIXA' AND
	           TYPE = 'P' 			                AND
              U.UID = O.UID                      AND
              U.NAME = USER)

DROP PROCEDURE ATUALIZA_FLUXO_DE_CAIXA
GO

CREATE PROCEDURE ATUALIZA_FLUXO_DE_CAIXA
   @P_CDEMPRESA   VARCHAR(02),
   @P_CDFILIAL    VARCHAR(04),
   @P_DTMOVFLUXO  DATETIME,
   @P_IDMOVFLUXO  VARCHAR(01),
   @P_CDCLASSFINA VARCHAR(06),
   @P_VRENTMFLUXO NUMERIC(16,2),
   @P_VRSAIMFLUXO NUMERIC(16,2)

AS

   DECLARE @V_EXISTE INTEGER;
   DECLARE @V_VRSAIMFLUXO  DOUBLE PRECISION;
   DECLARE @V_VRENTMFLUXO  DOUBLE PRECISION;

BEGIN
   SELECT
      @V_EXISTE = COUNT(*)
   FROM
      MOVFLUXO
   WHERE
      (CDEMPRESA   = @P_CDEMPRESA)  AND
      (CDFILIAL    = @P_CDFILIAL)   AND
      (DTMOVFLUXO  = @P_DTMOVFLUXO) AND
      (IDMOVFLUXO  = @P_IDMOVFLUXO) AND
      (CDCLASSFINA = @P_CDCLASSFINA);

   SET @V_VRSAIMFLUXO  = 0;
   SET @V_VRENTMFLUXO  = 0;

   IF NOT (@P_VRSAIMFLUXO IS NULL) BEGIN
      SET @V_VRSAIMFLUXO = @P_VRSAIMFLUXO;
   END;

   IF NOT (@P_VRENTMFLUXO IS NULL) BEGIN
      SET @V_VRENTMFLUXO = @P_VRENTMFLUXO;
   END;

   IF @V_EXISTE = 0 BEGIN
      INSERT INTO MOVFLUXO
         (CDEMPRESA,
          CDFILIAL,
          DTMOVFLUXO,
          IDMOVFLUXO,
          CDCLASSFINA,
          VRENTMFLUXO,
          VRSAIMFLUXO)
      VALUES
         (@P_CDEMPRESA,
          @P_CDFILIAL,
          @P_DTMOVFLUXO,
          @P_IDMOVFLUXO,
          @P_CDCLASSFINA,
          @V_VRENTMFLUXO,
          @V_VRSAIMFLUXO);
   END
   ELSE BEGIN
      UPDATE
         MOVFLUXO
      SET
         VRENTMFLUXO = VRENTMFLUXO + @V_VRENTMFLUXO,
         VRSAIMFLUXO = VRSAIMFLUXO + @V_VRSAIMFLUXO
      WHERE
         (CDEMPRESA   = @P_CDEMPRESA)  AND
         (CDFILIAL    = @P_CDFILIAL)   AND
         (DTMOVFLUXO  = @P_DTMOVFLUXO) AND
         (IDMOVFLUXO  = @P_IDMOVFLUXO) AND
         (CDCLASSFINA = @P_CDCLASSFINA);
   END;
END;
GO
